@@ -23,6 +23,7 @@ all the user actions to CEM fo logging/mentor input/game input."
 #include "../meam/jammo-editing-track.h"
 #include "../meam/jammo-recording-track.h"
 #include "../meam/jammo-instrument-track.h"
+#include "../meam/jammo-slider-track.h"
 
 #include "../gems/gems.h"
 
@@ -55,6 +56,7 @@ JammoEditingTrack* editing_track;
 JammoEditingTrack* backing_track;
 
 JammoInstrumentTrack* instrument_track;
+JammoSliderTrack* slider_track;
 JammoRecordingTrack* recording_track;
 
 gint number_of_themes = 0;
@@ -201,6 +203,22 @@ void chum_test_instrument(int type) {
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track));
 
 }
+void chum_test_slider(int type) {
+	cem_add_to_log(g_strdup_printf("chum_test_slider(%d)",type),LOG_DEBUG);
+	sequencer = jammo_sequencer_new();
+	slider_track = jammo_slider_track_new(type);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(slider_track));
+	
+  //Slider track doesn't work if there aren't another track with one sample.
+	editing_track = jammo_editing_track_new();
+	JammoSample* sample;
+	gchar* filepath1 = g_strdup_printf("%s/themes/forest/loop1.wav",DATA_DIR);
+	sample = jammo_sample_new_from_file(filepath1);
+	jammo_editing_track_add_sample(editing_track, sample, 0);
+	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track));
+
+}
+
 void chum_go_back() {
     cem_add_to_log(g_strdup_printf("chum_go_back(). state_of_chum was %s...",name_of_states[state_of_chum]),LOG_DEBUG);
 
@@ -331,15 +349,16 @@ gchar *name =  (gchar *) g_list_nth_data(chum_get_all_songs(),i); //FIXME. now i
 return name;
 }
 
-
-/*STATIC
-Always call this before gui_go_screen(SCREEN_PLAY_RECORDED);
-*/
+//N900 has very limited /tmp space.
 #ifdef N900
 #define RECORDING_FILENAME "/home/user/.jammo/recording.wav"
 #else
 #define RECORDING_FILENAME "/tmp/recording.wav"
 #endif
+
+/*STATIC
+Always call this before gui_go_screen(SCREEN_PLAY_RECORDED);
+*/
 static void chum_play_recorded_and_backing_track(){
     chum_stop_sequencer();
     /*
@@ -504,12 +523,12 @@ jammo_instrument_track_set_note(instrument_track,note,octave);
 }
 
 void chum_slider_freq(int a){
-jammo_instrument_track_set_slider_frequency(instrument_track,a);
+jammo_slider_track_set_frequency(slider_track,a);
 }
 
 
 void chum_slider_state(gboolean b){
-jammo_instrument_track_set_slider_state(instrument_track,b);
+jammo_slider_track_set_state(slider_track,b);
 }
 
 void chum_print_note_table(){
