@@ -21,6 +21,7 @@ This file is for clutter based gui and it handles config file reading
 //In n900 we should use /opt for data files. And maybe this is not bad place for all systems?
 
 #define DATA_DIR "/opt/jammo"
+#define SEQUENCER_DIR "/opt/jammo/sequencer"
 
 #define THEMES_DIR DATA_DIR "/themes"
 #define SONGS_DIR DATA_DIR "/songs"
@@ -29,6 +30,7 @@ extern JammoEditingTrack* editing_track;
 extern JammoEditingTrack* backing_track;
 
 void chum_test_instrument(int type);
+void chum_test_slider(int type);
 void chum_slider_freq(int a);
 void chum_slider_state(gboolean b);
 
