@@ -40,10 +40,39 @@ Read more about clutter: http://clutter-project.org/
 #include "midi_editor.h"
 #include "sequencer.h"
 ClutterActor* star_trace;
+ClutterActor* mentor; /*For mentor*/
+ClutterActor* to_main_menu; /*back to main menu*/
+ClutterActor* back_to_theme_selection; 
+ClutterActor* play_button;
+
+
+ClutterActor* stage;
+ClutterActor* main_getStage(){
+  return stage;
+}
+
 
 ClutterActor* get_real_star_trace(){
 return star_trace;
 }
+
+void back_to_main_menu(){
+chum_go_screen(SCREEN_GAME_SELECTION);
+}
+
+void back_to_theme_selection_pressed(){
+chum_stop_sequencer();
+chum_go_screen(SCREEN_THEME_SELECTION);
+}
+
+void mentor_pressed(){
+printf("mentor_pressed\n");
+}
+
+void do_play_button_press()  {
+chum_play_sequencer();
+}
+
 void gui_start_main_loop(){
     //clutter_init();
 		
@@ -61,8 +90,40 @@ void gui_start_main_loop(){
     clutter_texture_set_cogl_texture (CLUTTER_TEXTURE(star_trace), new_texture);
     cogl_handle_unref (new_texture);
 
+    //Init some general actor
+    mentor = config_get_configured_actor(NULL,"mentor");
+    clutter_container_add_actor (CLUTTER_CONTAINER (stage), mentor);
+    clutter_actor_hide (mentor);
+    clutter_actor_set_name(mentor, "to_main_menu");
+    clutter_actor_set_reactive(mentor, TRUE);
+    g_signal_connect (mentor, "button-press-event", G_CALLBACK (mentor_pressed),NULL);
+
+     //Back to main-menu button.
+    to_main_menu = config_get_configured_actor(NULL,"main");
+    clutter_container_add_actor (CLUTTER_CONTAINER (stage), to_main_menu);
+    clutter_actor_hide (to_main_menu);
+    clutter_actor_set_name(to_main_menu, "to_main_menu");
+    clutter_actor_set_reactive(to_main_menu, TRUE);
+    g_signal_connect (to_main_menu, "button-press-event", G_CALLBACK (back_to_main_menu),NULL);
+
+    //Back to theme-selection button.
+    back_to_theme_selection = config_get_configured_actor(NULL,"backtotheme");
+    clutter_container_add_actor (CLUTTER_CONTAINER (stage), back_to_theme_selection);
+    clutter_actor_hide (back_to_theme_selection);
+    clutter_actor_set_name(back_to_theme_selection, "to_main_menu");
+    clutter_actor_set_reactive(back_to_theme_selection, TRUE);
+    g_signal_connect (back_to_theme_selection, "button-press-event", G_CALLBACK (back_to_theme_selection_pressed),NULL);
+
+    play_button = config_get_configured_actor(NULL,"play");
+    clutter_container_add_actor (CLUTTER_CONTAINER (stage), play_button);
+    clutter_actor_hide (play_button);
+    clutter_actor_set_name(play_button, "to_main_menu");
+    clutter_actor_set_reactive(play_button, TRUE);
+    g_signal_connect (play_button, "button-press-event", G_CALLBACK (do_play_button_press),NULL);
+
+
+    printf("Calling clutter main\n");
 
-    
     clutter_main();
 }
 
@@ -79,10 +140,6 @@ ClutterColor *get_dark_color(){         return &dark_color;  }
 ClutterColor *get_blue_color(){         return &blue_color;  }
 ClutterColor *get_green_color(){         return &green_color;  }
 
-ClutterActor* stage;
-ClutterActor* main_getStage(){
-  return stage;
-}
 
 void gui_visualize_playing(int state) {
   if (state==SCREEN_COMPOSING)
@@ -99,22 +156,22 @@ void gui_go_screen(int screen_number) {
 	} else if (screen_number==SCREEN_WELCOME){
     show_welcome();              //welcome_demo.c
   } else if (screen_number==SCREEN_GAME_SELECTION){
-		main_menu_init();
     show_game_selection();        //main_menu.c
   } else if (screen_number==SCREEN_THEME_SELECTION){
-		composing_game_init_theme_selection();
     show_theme_selection();       //composing_game.c
   } else if (screen_number==SCREEN_COMPOSING){
-		composing_game_init_games(); 
     start_theme();               //composing_game.c
   } else if (screen_number==SCREEN_SONG_SELECTION){
-		init_singing_game(); 
     start_mobikid_selection();   //singing_game.c
   } else if (screen_number==SCREEN_SONG_RECORDING){
     start_mobikid_recording();   //singing_game.c
   } else if (screen_number==SCREEN_PLAY_RECORDED){
     start_mobikid_play_recorded();      //singing_game.c
-  } 
+  } else if (screen_number==SCREEN_MIDI_EDITOR){
+    start_midi_editor();                //midi_editor.c
+  } else if (screen_number==SCREEN_SEQUENCER){
+    start_sequencer();                //sequencer.c
+  }
 
 }
 
@@ -177,7 +234,7 @@ void gui_init() {
 
       #endif
       clutter_actor_show_all(stage);
-      //preloader_start(); //this will start some threads and return immediatly.
+      preloader_start(); //this will start some threads and return immediatly.
 
       #ifdef START_JOYSTICK_THREAD
       /* temporaly disabled */
