@@ -17,6 +17,7 @@ ClutterColor *get_transparency_color();
 ClutterColor *get_white_color();
 ClutterColor *get_dark_color();
 ClutterColor *get_blue_color();
+ClutterColor *get_green_color();
 
 ClutterActor* load_background(const char* theme_folder);
 ClutterActor* get_drop_area();
@@ -24,6 +25,7 @@ ClutterActor* main_getStage();
 
 void show_game_selection();
 void gui_visualize_playing(int state);
+void window_closed(void);
 
 typedef struct ActorBehaviour {
 	ClutterActor* actor;
