@@ -31,7 +31,7 @@ ClutterActor *easy_advanced;            /* Button for choosing easy VS advance *
 ClutterActor *choose_easy;
 ClutterActor *choose_advanced;
 
-ClutterActor *mentor; /*For mentor*/
+extern ClutterActor *mentor; /*For mentor*/
 ClutterActor *quit_confirmation; /*Are you sure you want quit -button*/
 ClutterActor *quit_cancel;       /*Are you sure you want quit -button*/
 
@@ -111,6 +111,7 @@ static void easy_advanced_callback(){
 }
 
 #include "../meam/jammo-instrument-track.h" //because of INSTRUMENT_TYPES
+#include "../meam/jammo-slider-track.h"  //because of SLIDER_TYPES
 static void init_actors() {
    ClutterActor* stage = main_getStage();
 
@@ -178,10 +179,6 @@ static void init_actors() {
    clutter_actor_hide (quit_cancel);
    clutter_container_add_actor (CLUTTER_CONTAINER (stage), quit_cancel);
 
-   mentor = config_get_configured_actor(NULL,"button-2"); //this is mentor/help button FIXME:name
-   clutter_container_add_actor (CLUTTER_CONTAINER (stage), mentor);
-   clutter_actor_hide (mentor);
-
    easy_advanced = config_get_configured_actor(NULL,"easy_advanced"); 
    clutter_container_add_actor (CLUTTER_CONTAINER (stage), easy_advanced);
    clutter_actor_hide (easy_advanced);
@@ -198,7 +195,7 @@ static void init_actors() {
    select_slider = config_get_configured_actor(NULL,"select_slider");
    clutter_actor_set_name(select_slider, "select_slider");
    clutter_actor_set_reactive(select_slider, TRUE);
-   g_signal_connect (select_slider, "button-press-event", G_CALLBACK (start_slider),GINT_TO_POINTER(JAMMO_INSTRUMENT_TYPE_SLIDER));
+   g_signal_connect (select_slider, "button-press-event", G_CALLBACK (start_slider),GINT_TO_POINTER(JAMMO_SLIDER_TYPE_KARPLUS)); //karplus-strong
    clutter_actor_hide (select_slider);
    clutter_container_add_actor (CLUTTER_CONTAINER (stage), select_slider);
 
