@@ -19,8 +19,8 @@ Objects are those icons which user can drag from playing area to timeline area.
 //private functions
 static void add_object_to_group(ClutterActor* actor,ClutterActor* group);
 
-JammoTexture *dragging = NULL;		     /*object which is currently dragged*/
-gint x_start_of_dragging, y_start_of_dragging, x_drag_offset, y_drag_offset;   /*these are related to dragging also*/
+static JammoTexture *dragging = NULL;		     /*object which is currently dragged*/
+static gint x_start_of_dragging, y_start_of_dragging, x_drag_offset, y_drag_offset;   /*these are related to dragging also*/
 
 
 
@@ -30,7 +30,7 @@ dragged object. This is because only watching dragged object we lost it if mouse
 moves too fast and isn't anymore top of object.
 */
 //void mouse_motion_on_stage(ClutterActor *actor, ClutterEvent *event, gpointer data) {
-void motion_on_object(ClutterActor *actor, ClutterEvent *event, gpointer data) {
+static void motion_on_object(ClutterActor *actor, ClutterEvent *event, gpointer data) {
   gfloat x_mouse_position_f, y_mouse_position_f;
 /*
 clutter_event_get_coords (event,&x_mouse_position, &y_mouse_position);
@@ -342,7 +342,7 @@ if (width_of_new+x_release>WIDTH_OF_WINDOW) {
           id_of_actor = clutter_get_script_id(G_OBJECT(actor));
 
           ClutterActor* new_actor;
-          new_actor = config_get_configured_actor(chum_get_theme_folder(chum_get_current_theme()),  (gchar*)id_of_actor);
+          new_actor = config_respawn_loop_actor(chum_get_theme_folder(chum_get_current_theme()),  (gchar*)id_of_actor);
           if (new_actor ==NULL)
               printf("new_actor is NULL\n");
           if (parent_group ==NULL)
