@@ -7,6 +7,8 @@ This file is for clutter based gui.
 #define _SEQUENCER_H_
 
 void start_sequencer();
+void init_sequencer();
+gboolean sequencer_is_initialized();
 
 #endif /* _SEQUENCER_H_ */
 
